"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MainSlim = void 0;
const SquareDrawer_1 = require("./ShapeDrawers/SquareDrawer");
const TextDrawer_1 = require("./ShapeDrawers/TextDrawer");
const ImageDrawer_1 = require("./ShapeDrawers/ImageDrawer");
const Utils_1 = require("./Utils");
const LineDrawer_1 = require("./ShapeDrawers/LineDrawer");
const CircleDrawer_1 = require("./ShapeDrawers/CircleDrawer");
const TriangleDrawer_1 = require("./ShapeDrawers/TriangleDrawer");
const StarDrawer_1 = require("./ShapeDrawers/StarDrawer");
const PolygonDrawer_1 = require("./ShapeDrawers/PolygonDrawer");
const Loader_1 = require("./Core/Loader");
const Bouncer_1 = require("./Interactions/External/Bouncer");
const Bubbler_1 = require("./Interactions/External/Bubbler");
const Connector_1 = require("./Interactions/External/Connector");
const Grabber_1 = require("./Interactions/External/Grabber");
const Attractor_1 = require("./Interactions/External/Attractor");
const Repulser_1 = require("./Interactions/External/Repulser");
const Attractor_2 = require("./Interactions/Particles/Attractor");
const Collider_1 = require("./Interactions/Particles/Collider");
const Infecter_1 = require("./Interactions/Particles/Infecter");
const Repulser_2 = require("./Interactions/Particles/Repulser");
const Linker_1 = require("./Interactions/Particles/Linker");
const LifeUpdater_1 = require("./Updaters/LifeUpdater");
const OpacityUpdater_1 = require("./Updaters/OpacityUpdater");
const SizeUpdater_1 = require("./Updaters/SizeUpdater");
const AngleUpdater_1 = require("./Updaters/AngleUpdater");
const ColorUpdater_1 = require("./Updaters/ColorUpdater");
const StrokeColorUpdater_1 = require("./Updaters/StrokeColorUpdater");
const OutOfCanvasUpdater_1 = require("./Updaters/OutOfCanvasUpdater");
class MainSlim {
    constructor() {
        this.initialized = false;
        const squareDrawer = new SquareDrawer_1.SquareDrawer();
        const textDrawer = new TextDrawer_1.TextDrawer();
        const imageDrawer = new ImageDrawer_1.ImageDrawer();
        Utils_1.Plugins.addParticleUpdater((container) => new LifeUpdater_1.LifeUpdater(container));
        Utils_1.Plugins.addParticleUpdater((container) => new OpacityUpdater_1.OpacityUpdater(container));
        Utils_1.Plugins.addParticleUpdater((container) => new SizeUpdater_1.SizeUpdater(container));
        Utils_1.Plugins.addParticleUpdater((container) => new AngleUpdater_1.AngleUpdater(container));
        Utils_1.Plugins.addParticleUpdater((container) => new ColorUpdater_1.ColorUpdater(container));
        Utils_1.Plugins.addParticleUpdater((container) => new StrokeColorUpdater_1.StrokeColorUpdater(container));
        Utils_1.Plugins.addParticleUpdater((container) => new OutOfCanvasUpdater_1.OutOfCanvasUpdater(container));
        Utils_1.Plugins.addInteractor((container) => new Bouncer_1.Bouncer(container));
        Utils_1.Plugins.addInteractor((container) => new Bubbler_1.Bubbler(container));
        Utils_1.Plugins.addInteractor((container) => new Connector_1.Connector(container));
        Utils_1.Plugins.addInteractor((container) => new Grabber_1.Grabber(container));
        Utils_1.Plugins.addInteractor((container) => new Attractor_1.Attractor(container));
        Utils_1.Plugins.addInteractor((container) => new Repulser_1.Repulser(container));
        Utils_1.Plugins.addInteractor((container) => new Attractor_2.Attractor(container));
        Utils_1.Plugins.addInteractor((container) => new Collider_1.Collider(container));
        Utils_1.Plugins.addInteractor((container) => new Infecter_1.Infecter(container));
        Utils_1.Plugins.addInteractor((container) => new Repulser_2.Repulser(container));
        Utils_1.Plugins.addInteractor((container) => new Linker_1.Linker(container));
        Utils_1.Plugins.addShapeDrawer("line", new LineDrawer_1.LineDrawer());
        Utils_1.Plugins.addShapeDrawer("circle", new CircleDrawer_1.CircleDrawer());
        Utils_1.Plugins.addShapeDrawer("edge", squareDrawer);
        Utils_1.Plugins.addShapeDrawer("square", squareDrawer);
        Utils_1.Plugins.addShapeDrawer("triangle", new TriangleDrawer_1.TriangleDrawer());
        Utils_1.Plugins.addShapeDrawer("star", new StarDrawer_1.StarDrawer());
        Utils_1.Plugins.addShapeDrawer("polygon", new PolygonDrawer_1.PolygonDrawer());
        Utils_1.Plugins.addShapeDrawer("char", textDrawer);
        Utils_1.Plugins.addShapeDrawer("character", textDrawer);
        Utils_1.Plugins.addShapeDrawer("image", imageDrawer);
        Utils_1.Plugins.addShapeDrawer("images", imageDrawer);
    }
    init() {
        if (!this.initialized) {
            this.initialized = true;
        }
    }
    loadFromArray(tagId, options, index) {
        return __awaiter(this, void 0, void 0, function* () {
            return Loader_1.Loader.load(tagId, options, index);
        });
    }
    load(tagId, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return Loader_1.Loader.load(tagId, options);
        });
    }
    set(id, element, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return Loader_1.Loader.set(id, element, options);
        });
    }
    loadJSON(tagId, pathConfigJson, index) {
        return Loader_1.Loader.loadJSON(tagId, pathConfigJson, index);
    }
    setOnClickHandler(callback) {
        Loader_1.Loader.setOnClickHandler(callback);
    }
    dom() {
        return Loader_1.Loader.dom();
    }
    domItem(index) {
        return Loader_1.Loader.domItem(index);
    }
    addShape(shape, drawer, init, afterEffect, destroy) {
        let customDrawer;
        if (typeof drawer === "function") {
            customDrawer = {
                afterEffect: afterEffect,
                destroy: destroy,
                draw: drawer,
                init: init,
            };
        }
        else {
            customDrawer = drawer;
        }
        Utils_1.Plugins.addShapeDrawer(shape, customDrawer);
    }
    addPreset(preset, options) {
        Utils_1.Plugins.addPreset(preset, options);
    }
    addPlugin(plugin) {
        Utils_1.Plugins.addPlugin(plugin);
    }
    addNoiseGenerator(name, generator) {
        Utils_1.Plugins.addNoiseGenerator(name, generator);
    }
    addInteractor(interactorInitializer) {
        Utils_1.Plugins.addInteractor(interactorInitializer);
    }
    addParticleUpdater(updaterInitializer) {
        Utils_1.Plugins.addParticleUpdater(updaterInitializer);
    }
}
exports.MainSlim = MainSlim;
